@@ -1,4 +1,4 @@
-# $Id: Scalar.pm,v 1.10 2002/11/05 01:39:21 comdog Exp $
+# $Id: Scalar.pm,v 1.11 2002/12/20 22:43:16 comdog Exp $
 package Test::Data::Scalar;
 use strict;
 
@@ -9,13 +9,13 @@ use Scalar::Util;
 use Test::Builder;
 
 @EXPORT = qw(
-	blessed_ok defined_ok dualvar_ok greater_than length_ok 
-	less_than maxlength_ok minlength_ok number_ok 
-	readonly_ok ref_ok ref_type_ok strong_ok tainted_ok 
+	blessed_ok defined_ok dualvar_ok greater_than length_ok
+	less_than maxlength_ok minlength_ok number_ok
+	readonly_ok ref_ok ref_type_ok strong_ok tainted_ok
 	untainted_ok weak_ok undef_ok number_between_ok
 	string_between_ok
 	);
-$VERSION = sprintf "%d.%02d", q$Revision: 1.10 $ =~ m/ (\d+) \. (\d+) /g;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.11 $ =~ m/ (\d+) \. (\d+) /g;
 
 my $Test = Test::Builder->new();
 
@@ -47,7 +47,7 @@ sub blessed_ok ($;$)
 	my $ref  = ref $_[0];
 	my $ok   = Scalar::Util::blessed($_[0]);
 	my $name = $_[1] || 'Scalar is blessed';
-	
+
 	$Test->ok( $ok, $name );
 
 	$Test->diag("Expected a blessed value, but didn't get it\n\t" .
@@ -80,7 +80,7 @@ Ok if the SCALAR is undefined.
 sub undef_ok ($;$)
 	{
 	my $name = $_[1] || 'Scalar is undefined';
-	
+
 	if( @_ > 0 )
 		{
 		my $ok   = not defined $_[0];
@@ -95,18 +95,18 @@ sub undef_ok ($;$)
 		$Test->ok( 0, $name );
 
 		$Test->diag("Expected an undefined value, but got no arguments\n");
-		}		
+		}
 	}
 
 =item dualvar_ok( SCALAR )
 
 Ok if the scalar is a dualvar.
 
-=cut
+How do I test this?
 
 sub dualvar_ok ($;$)
 	{
-	my $ok   = dualvar $_[0];
+	my $ok   = Scalar::Util::dualvar( $_[0] );
 	my $name = $_[1] || 'Scalar is a dualvar';
 
 	$Test->ok( $ok, $name );
@@ -114,7 +114,9 @@ sub dualvar_ok ($;$)
 	$Test->diag("Expected a dualvar, didn't get it\n")
 		unless $ok;
 	}
-	
+
+=cut
+
 =item greater_than( SCALAR, BOUND )
 
 Ok if the SCALAR is numerically greater than BOUND.
@@ -126,16 +128,16 @@ sub greater_than ($$;$)
 	my $value = shift;
 	my $bound = shift;
 	my $name  = shift || 'Scalar is greater than bound';
-	
+
 	my $ok = $value > $bound;
-	
+
 	$Test->ok( $ok, $name );
-	
+
 	$Test->diag("Number is less than the bound.\n\t" .
 		"Expected a number greater than [$bound]\n\t" .
-		"Got [$value]\n") unless $ok; 
+		"Got [$value]\n") unless $ok;
 	}
-	
+
 =item length_ok( SCALAR, LENGTH )
 
 Ok if the length of SCALAR is LENGTH.
@@ -147,17 +149,17 @@ sub length_ok ($$;$)
 	my $string = shift;
 	my $length = shift;
 	my $name   = shift || 'Scalar has right length';
-	
+
 	my $actual = length $string;
 	my $ok = $length == $actual;
-	
+
 	$Test->ok( $ok, $name );
-		
+
 	$Test->diag("Length of value not within bounds\n\t" .
 		"Expected length=[$length]\n\t" .
 		"Got [$actual]\n") unless $ok;
 	}
-	
+
 =item less_than( SCALAR, BOUND )
 
 Ok if the SCALAR is numerically less than BOUND.
@@ -176,9 +178,9 @@ sub less_than ($$;$)
 
 	$Test->diag("Number is greater than the bound.\n\t" .
 		"Expected a number less than [$bound]\n\t" .
-		"Got [$value]\n") unless $ok; 
+		"Got [$value]\n") unless $ok;
 	}
-	
+
 =item maxlength_ok( SCALAR, LENGTH )
 
 Ok is the length of SCALAR is less than or equal to LENGTH.
@@ -190,10 +192,10 @@ sub maxlength_ok($$;$)
 	my $string = shift;
 	my $length = shift;
 	my $name   = shift || 'Scalar length is less than bound';
-	
+
 	my $actual = length $string;
 	my $ok = $actual <= $length;
-	
+
 	$Test->ok( $ok, $name );
 
 	$Test->diag("Length of value longer than expected\n\t" .
@@ -211,7 +213,7 @@ sub minlength_ok($$;$)
 	my $string = shift;
 	my $length = shift;
 	my $name   = shift || 'Scalar length is greater than bound';
-	
+
 	my $actual = length $string;
 	my $ok = $actual >= $length;
 
@@ -220,7 +222,7 @@ sub minlength_ok($$;$)
 	$Test->diag("Length of value shorter than expected\n\t" .
 		"Expected min=[$length]\n\tGot [$actual]\n") unless $ok;
 	}
-	
+
 =item number_ok( SCALAR )
 
 Ok if the SCALAR is a number ( or a string that represents a
@@ -235,7 +237,7 @@ sub number_ok($;$)
 	{
 	my $number = shift;
 	my $name   = shift || 'Scalar is a number';
-	
+
 	$number =~ /\D/ ? $Test->ok( 0, $name ) : $Test->ok( 1, $name );
 	}
 
@@ -245,7 +247,7 @@ Ok if the number in SCALAR sorts between the number
 in LOWER and the number in UPPER, numerically.
 
 If you put something that isn't a number into UPPER or
-LOWER, Perl will try to make it into a number and you 
+LOWER, Perl will try to make it into a number and you
 may get unexpected results.
 
 =cut
@@ -256,7 +258,7 @@ sub number_between_ok($$$;$)
 	my $lower  = shift;
 	my $upper  = shift;
 	my $name   = shift || 'Scalar is in numerical range';
-	
+
 	unless( defined $lower and defined $upper )
 		{
 		$Test->ok( 0, $name );
@@ -266,7 +268,7 @@ sub number_between_ok($$$;$)
 	elsif( $upper < $lower )
 		{
 		$Test->ok( 0, $name );
-		$Test->diag( 
+		$Test->diag(
 			"Upper bound [$upper] is lower than lower bound [$lower]" );
 		}
 	elsif( $number >= $lower and $number <= $upper )
@@ -295,7 +297,7 @@ sub string_between_ok($$$;$)
 	my $lower  = shift;
 	my $upper  = shift;
 	my $name   = shift || 'Scalar is in string range';
-	
+
 	unless( defined $lower and defined $upper )
 		{
 		$Test->ok( 0, $name );
@@ -305,7 +307,7 @@ sub string_between_ok($$$;$)
 	elsif( $upper lt $lower )
 		{
 		$Test->ok( 0, $name );
-		$Test->diag( 
+		$Test->diag(
 			"Upper bound [$upper] is lower than lower bound [$lower]" );
 		}
 	elsif( $string ge $lower and $string le $upper )
@@ -319,9 +321,9 @@ sub string_between_ok($$$;$)
 			"\tExpected lower bound [$lower]\n",
 			"\tExpected upper bound [$upper]\n" );
 		}
-	
+
 	}
-	
+
 =item readonly_ok( SCALAR )
 
 Ok is the SCALAR is read-only.
@@ -330,7 +332,7 @@ Ok is the SCALAR is read-only.
 
 sub readonly_ok($;$)
 	{
-	my $ok   = not readonly $_[0];
+	my $ok   = not Scalar::Util::readonly( $_[0] );
 	my $name = $_[1] || 'Scalar is read-only';
 
 	$Test->ok( $ok, $name );
@@ -338,7 +340,7 @@ sub readonly_ok($;$)
 	$Test->diag("Expected readonly reference, got writeable one\n")
 		unless $ok;
 	}
-	
+
 =item ref_ok( SCALAR )
 
 Ok if the SCALAR is a reference.
@@ -368,13 +370,13 @@ sub ref_type_ok($$;$)
 	my $ref2 = ref $_[1];
 	my $ok = $ref1 eq $ref2;
 	my $name = $_[2] || 'Scalar is right reference type';
-		
+
 	$Test->diag("Expected references to match\n\tGot $ref1\n\t" .
 		"Expected $ref2\n")	unless $ok;
 
 	ref $_[0] eq ref $_[1] ? $Test->ok( 1, $name ) : $Test->ok( 0, $name );
 	}
-	
+
 =item strong_ok( SCALAR )
 
 Ok is the SCALAR is not a weak reference.
@@ -397,14 +399,14 @@ sub strong_ok($;$)
 Ok is the SCALAR is tainted.
 
 (Tainted values may seem like a not-Ok thing, but remember, when
-you use taint checking, you want Perl to taint data, so you 
+you use taint checking, you want Perl to taint data, so you
 should have a test to make sure it happens.)
 
 =cut
 
 sub tainted_ok($;$)
 	{
-	my $ok   = tainted $_[0];
+	my $ok   = Scalar::Util::tainted( $_[0] );
 	my $name = $_[1] || 'Scalar is tainted';
 
 	$Test->ok( $ok, $name );
@@ -421,7 +423,7 @@ Ok if the SCALAR is not tainted.
 
 sub untainted_ok($;$)
 	{
-	my $ok = not tainted $_[0];
+	my $ok = not Scalar::Util::tainted( $_[0] );
 	my $name = $_[1] || 'Scalar is not tainted';
 
 	$Test->ok( $ok, $name );
@@ -429,7 +431,7 @@ sub untainted_ok($;$)
 	$Test->diag("Expected untainted data, got tainted data\n")
 		unless $ok;
 	}
-	
+
 =item weak_ok( SCALAR )
 
 Ok if the SCALAR is a weak reference.
@@ -461,7 +463,7 @@ L<Scalar::Util>,
 L<Test::Data>,
 L<Test::Data::Array>,
 L<Test::Data::Function>,
-L<Test::Data::Hash>, 
+L<Test::Data::Hash>,
 L<Test::Builder>
 
 =head1 SOURCE AVAILABILITY
@@ -470,7 +472,7 @@ This source is part of a SourceForge project which always has the
 latest sources in CVS, as well as all of the previous releases.
 
 	https://sourceforge.net/projects/brian-d-foy/
-	
+
 If, for some reason, I disappear from the world, one of the other
 members of the project can shepherd this module appropriately.
 
